@@ -81,7 +81,7 @@ class Weather:
 
     namespaces = {
         "kml": "http://www.opengis.net/kml/2.2",
-        "dwd": "https://opendata.dwd.de/weather/lib/pointforecast_dwd_extension_V1_0.xsd",
+        "dwd": "http://opendata.dwd.de/weather/lib/pointforecast_dwd_extension_V1_0.xsd",
     }
 
     weather_codes = {
@@ -203,14 +203,65 @@ class Weather:
         return None
 
     def get_condition(self, weather_data):
+
+        if len(weather_data) == 0:
+            return None
+        if len(weather_data) == 1:
+            return self.weather_codes[weather_data[0][WeatherDataType.CONDITION.value]][
+                0
+            ]
+
         priority = 99
         condition_text = ""
+        sunny_counter = 1
+        cloudy_counter = 1
+        rainy_counter = 0
+        snowy_counter = 0
+        thunder_counter = 0
+        fog_counter = 0
+
         for item in weather_data:
             if item[WeatherDataType.CONDITION.value] != "-":
                 condition = self.weather_codes[item[WeatherDataType.CONDITION.value]]
+                if condition[0] == "sunny":
+                    sunny_counter += 1
+                if condition[0] == "cloudy":
+                    cloudy_counter += 1
+                if condition[0] == "fog":
+                    fog_counter += 1
+                if condition[0] == "rainy":
+                    rainy_counter += 1
+                if condition[0] == "snowy":
+                    snowy_counter += 1
+                if condition[0] == "lightning-rainy":
+                    thunder_counter += 1
+
                 if condition[1] < priority:
                     priority = condition[1]
                     condition_text = condition[0]
+
+        if cloudy_counter / sunny_counter > 0.7:
+            condition_text = "cloudy"
+        elif cloudy_counter / sunny_counter > 0.2:
+            condition_text = "partlycloudy"
+        else:
+            condition_text = "sunny"
+        if fog_counter / len(weather_data) > 0.5:
+            condition_text = "fog"
+        print(snowy_counter / len(weather_data))
+        if snowy_counter / len(weather_data) > 0.2:
+            condition_text = "snowy"
+
+        print(rainy_counter / len(weather_data))
+        if rainy_counter / len(weather_data) > 0.2:
+            if condition_text == "snowy":
+                condition_text = "snowy-rainy"
+            else:
+                condition_text = "rainy"
+
+        if thunder_counter > 0:
+            condition_text = "lightning-rainy"
+
         return str(condition_text)
 
     def get_timeframe_max(
@@ -320,6 +371,33 @@ class Weather:
                 value_sum += float(value)
         return round(value_sum, 2)
 
+    def get_timeframe_avg(
+        self,
+        weatherDataType: WeatherDataType,
+        timestamp: datetime,
+        timeframe: int,
+        shouldUpdate=True,
+    ):
+        if shouldUpdate:
+            self.update()
+        if self.is_valid_timeframe(timeframe):
+            return self.get_avg(
+                self.get_timeframe_values(timestamp, timeframe), weatherDataType
+            )
+        return None
+
+    def get_avg(_, weather_data, weatherDataType):
+        value_sum = 0.0
+        count = len(weather_data)
+        if count != 0:
+            for item in weather_data:
+                value = item[weatherDataType.value]
+                if value:
+                    value_sum += float(value)
+            return round(value_sum/len(weather_data), 2)
+        else:
+            return None
+
     def get_timeframe_values(self, timestamp: datetime, timeframe: int):
         "timestamp has to be checked prior to be in timerange"
         result = []
@@ -525,7 +603,7 @@ def download_weather_report(region_code):
 
 
 def download_latest_kml(stationid):
-    url = f"https://opendata.dwd.de/weather/local_forecasts/mos/MOSMIX_L/single_stations/{stationid}/kml/MOSMIX_L_LATEST_{stationid}.kmz"
+    url = f"http://opendata.dwd.de/weather/local_forecasts/mos/MOSMIX_L/single_stations/{stationid}/kml/MOSMIX_L_LATEST_{stationid}.kmz"
     request = requests.get(url)
     file = BytesIO(request.content)
     kmz = ZipFile(file, "r")
